@@ -98,7 +98,7 @@ $header = '<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01//EN">
     <body link="#0000FF" vlink="#0000FF">
     <div class="header"><img src="img/logo.jpg" width=114 height=48 border=0 alt="OPList">';
 
-$footer = '</div><div class="footer"><small>&copy; 2011 by <a href="http://software.glawar.at/oplist/" target="_blank">OPList</a> v1.11.574 (2014-11-19)</small></div></body></html>';
+$footer = '</div><div class="footer"><small>&copy; 2011 by <a href="http://software.glawar.at/oplist/" target="_blank">OPList</a> v2.0.579 (2014-11-21)</small></div></body></html>';
 
 
 session_start();
@@ -758,7 +758,6 @@ if (empty($_SESSION['OPUID']) || empty($_SESSION['OPGID'])) {
         } else {
             $OPAID = $_POST['OPAID'];
         }
-
         $sQuery = "INSERT INTO OPLIST (OPID, OPDATECREATED, OPDATEUPDATED, OPSID, OPENTRY, OPAID, OPDESC, OPPID, OPPRIO, OPUID_ASSIGNED, OPUID_CREATED, OPUID_UPDATED)  VALUES (".$nextId."," .
             $dateNow . ", ".$dateNow.", 1, " .
              "'" . str_replace("'","''",$_POST['OPENTRY']) . "'," .
@@ -775,6 +774,69 @@ if (empty($_SESSION['OPUID']) || empty($_SESSION['OPGID'])) {
         $result = getRessource($sQuery);
         echo getError();
         freeRessource($result);
+		
+		# determine the id of the op entry
+		$sQuery = "SELECT OPID FROM OPLIST WHERE OPENTRY = '" . str_replace("'","''",$_POST['OPENTRY']) . "' ORDER BY OPDATECREATED DESC";
+		debugIntoFile("Get-ID of actual OP-Query: <".$sQuery.">");
+        $result = getRessource($sQuery);
+        echo getError();
+        
+        $foundOPID = 0;
+        while ($val = getRow($result)) {
+			if ($foundOPID == 0) {
+				$foundOPID = $val['OPID'];
+				logIntoFile("ID of last inserted OPEntry <".$val['OPID'].">");
+            }
+        }
+        freeRessource($result);
+		
+		# add file if some added
+		if (!empty($_FILES['datei']['name'])) {
+            if ($usedb == "mysql") {
+				$nextId = "null";
+                $sQuery = "INSERT INTO OPLIST_FILE (OPLFT) VALUES (1)";
+                debugIntoFile("Naechste-File-Id-ermitteln-Select: <".$sQuery.">");
+                #if ($debugSQL == 1) {
+                #    echo "<p><b>Naechste File-Id ermitteln-Select:</b>".$sQuery."</p>";
+                #}
+                $result = getRessource($sQuery);
+                freeRessource($result);
+
+                $newFileName = mysql_insert_id();
+            } else if ($usedb == "oracle") {
+				$nextId="OPLISTCOMMENT_SEQ.nextval";
+                $sQuery = "SELECT OPLISTFILENAME_SEQ.NEXTVAL FROM DUAL";
+                debugIntoFile("Naechstes-Attachment-Select: <".$sQuery.">");
+                #if ($debugSQL == 1) {
+                #    echo "<p><b>Naechster Attachment-Select:</b>".$sQuery."</p>";
+                #}
+                $result = getRessource($sQuery);
+                echo getError();
+                while ($val = getRow($result)) {
+                    $newFileName = $val['NEXTVAL'];
+                }
+                freeRessource($result);
+            }
+
+            $file_namerev = strrev($_FILES['datei']['name']);
+            $parts = explode(".", $file_namerev);
+            $endung = strrev($parts[0]);
+            #echo "Dateiendung: ".$endung."<br>";
+            $newFileName .= ".".$endung;
+            #echo "A2".$newFileName."<br>";
+
+            if (!move_uploaded_file($_FILES['datei']['tmp_name'], "uploads/".$newFileName)) {
+                echo "Die Datei ".$_FILES['datei']['name']." konnte nicht gespeichert werden.";
+            }
+            $newFileName = "'".$newFileName."'";
+			$sQuery = "INSERT INTO OPLIST_COMMENT (OPCID, OPUID, OPCTEXT, OPID, OPCPRIVATE, OPCFILENAME) VALUES (".$nextId.", ".$_SESSION['OPUID'].", 'Dateianhang zur OP-Beschreibung oben', ".$foundOPID.", 0, ".$newFileName.")";
+			debugIntoFile("Insert-Attachment-Select: <".$sQuery.">");
+			$result = getRessource($sQuery);
+			echo getError();
+			freeRessource($result);
+        }
+		
+		
         #logIntoFile("I am the debug Tester");
         logIntoFile("mailModus <".$mailModus.">");
         logIntoFile("debugMail <".$debugMail.">");
@@ -806,6 +868,8 @@ if (empty($_SESSION['OPUID']) || empty($_SESSION['OPGID'])) {
         }
     } else if (isset($_POST['addcomment'])) {
         $OPCPRIVATE = "0";
+		
+		
 
         if (isset ($_POST["OPCHANGESTATUS"]) && $_POST["OPCHANGESTATUS"] == "on") {
             // we will change the status directly
@@ -830,6 +894,14 @@ if (empty($_SESSION['OPUID']) || empty($_SESSION['OPGID'])) {
                 freeRessource($result);
             }
         }
+		
+		if (isset ($_POST["OPSIDNEW"])) {
+			$sQuery = "UPDATE OPLIST set OPSID = ".$_POST["OPSIDNEW"]." WHERE OPID = ".$_POST["OPID"];
+			debugIntoFile("update status of op entry: <".$sQuery.">");
+			$result = getRessource($sQuery);
+			echo getError();
+			freeRessource($result);
+		}
 
 
         if (isset ($_POST["OPCPRIVATE"]) && $_POST["OPCPRIVATE"] == "on") {
@@ -1380,8 +1452,37 @@ ORDER BY OP.OPSID ASC, OP.OPPRIO DESC, OP.OPDATEUPDATED DESC, OP.OPDATEUPDATED D
         $tmpHTML .= '
 
             </td>
-            <td colspan=2 align=right valign=bottom>
-            <input type="submit" name="addcomment" style="width:180px;" value="Kommentar hinzufügen" onClick="return(checkAddComment(document.addcommentform.OPCTEXT.value));">
+            <td colspan=2 align=right valign=bottom>';
+			if ($_SESSION['OPGID'] != "2") {
+				$tmpHTML .= '
+				<b>Status</b>
+				<select name="OPSIDNEW">';
+				
+					$sQuery = "SELECT OPSID FROM OPLIST WHERE OPID = ".$_GET['OPID'];
+					debugIntoFile("get status id of op entry: <".$sQuery.">");
+					$result = getRessource($sQuery);
+					echo getError();
+					
+					$foundOPStatusID = 0;
+					while ($val = getRow($result)) {
+						$foundOPStatusID = $val['OPSID'];
+					}
+					freeRessource($result);
+
+					foreach ($statArr as $k => $v) {
+						if ($foundOPStatusID == $v['OPSID']) {
+							$tmpHTML .=  '<option selected value="'.$v['OPSID'].'">' . $v['OPSTEXT'];
+						} else {
+							$tmpHTML .=  '<option value="'.$v['OPSID'].'">' . $v['OPSTEXT'];
+						}
+					}
+				
+				
+				$tmpHTML .= '
+						</select><div>&nbsp;</div><div>&nbsp;</div>';
+			}
+			$tmpHTML .= '
+			<input type="submit" name="addcomment" style="width:180px;" value="Kommentar hinzufügen" onClick="return(checkAddComment(document.addcommentform.OPCTEXT.value));">
             <input type="hidden" name="OPID" value="'.$_GET['OPID'].'">
             </td>
             </tr>
@@ -1391,7 +1492,7 @@ ORDER BY OP.OPSID ASC, OP.OPPRIO DESC, OP.OPDATEUPDATED DESC, OP.OPDATEUPDATED D
             <br><br><br>';
     } else if ($mode == "new" || $mode == "edit") {
         $tmpHTML .= '
-            <form method="post" action="'.$_SERVER['PHP_SELF'].'" name="opform">
+            <form method="post" action="'.$_SERVER['PHP_SELF'].'" name="opform" enctype="multipart/form-data">
             <table width=100% border="0" cellpadding=3 cellspacing=2>';
 
         if ($mode == "edit") {
@@ -1474,7 +1575,13 @@ ORDER BY OP.OPSID ASC, OP.OPPRIO DESC, OP.OPDATEUPDATED DESC, OP.OPDATEUPDATED D
             <td valign=top>&nbsp;<b>Beschreibung:</b></td>
             <td colspan=2><textarea name="OPDESC" style="width:650px;" rows=10>'.$OPDESC.'</textarea></td>
             <td bgcolor="#ffffff" ></td>
-        </tr>';
+        </tr>
+		<tr bgcolor="#f0f0f0" >
+			<td valign=top>&nbsp;<b>Anhang:</b></td>
+			<td colspan=2><input type="file" name="datei"></td>
+			<td bgcolor="#ffffff" ></td>
+		</tr>
+		';
         if ($_SESSION['OPGID'] == "1" || $_SESSION['OPGID'] == "4") {
             $tmpHTML .= '<tr bgcolor="#f0f0f0" >
                 <td valign=middle>&nbsp;<b>Zugewiesen an:</b></td>
